import React, { useEffect, useRef } from "react";
import MenuItem from "./langMenuItem";
import { useDispatch } from "react-redux";
import { actions as userActions } from "@redux/userRedux";
import { languages } from "data/language";

export default function Lang({ hideMenu }: { hideMenu: Function }) {
   const menuRef = useRef(null);
   const dispatch = useDispatch();
   const changeLanguage = (language: string) => {
      dispatch(userActions.setLanguage(language));
      hideMenu();
   };
   useEffect(() => {
      const handleClickOutside = (event: Event) => {
         if (menuRef.current && !menuRef.current.contains(event.target)) {
            hideMenu();
         }
      };
      document.addEventListener("mousedown", handleClickOutside);
      return () => {
         document.removeEventListener("mousedown", handleClickOutside);
      };
   }, [hideMenu]);

   return (
      <div className="lang-dropdown" ref={menuRef}>
         <MenuItem
            onClick={() => {
               changeLanguage(languages.english);
            }}
            name=" English "
            imageSrcOnHover="images/globeb.png"
            imageSrc="images/globe.png"
            alt="ICON"
            to="/"
         />
         <MenuItem
            onClick={() => {
               changeLanguage(languages.bengali);
            }}
            name=" বাংলা "
            imageSrcOnHover="images/map-pinb.png"
            imageSrc="images/map-pin.png"
            alt="ICON"
            to="/"
         />
      </div>
   );
}
